/** \file OTBBO.h
*   \brief OTBBO class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BBO_H
#define _OT_BBO_H

#include "OTDef.h"
  
  /// <summary>
  /// The best bid or offer - this is half of a quote. 
  /// These get sent when only one side is changing.
  /// </summary>
  class   OTBBO
  {
    public:
      /// <summary> Default constructor. </summary>
      OTBBO();

      /// <summary> Destructor. </summary>
      ~OTBBO();

      /// <returns>ID of appropriate request.</returns>
      int     getRequestId();

      /// <returns>Time when the event occurred.</returns> 
      int     getTimestamp();

      /// <returns>Size.</returns> 
      int     getSize();

      /// <returns>Side: B = Bid. A = Ask.</returns> 
      char    getSide();

      /// <returns>Symbol code; this field is provided for option chains only, 
      /// because there can be more than one symbol appropriate 
      /// to the requested underlyer and expiry date.</returns> 
      char   *getSymbol();

      /// <returns>Exchange code.</returns> 
      char   *getExchange();

      /// <returns>Price.</returns> 
      double  getPrice();

      /// <summary>Sets ID of appropriate request.</summary>
      /// <param name="requestId">ID of appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>Sets size.</summary>
      /// <param name="size">Size.</param>
      void setSize (int size);      

      /// <summary>Sets side: B = Bid. A = Ask.</summary>
      /// <param name="side">Side: B = Bid. A = Ask.</param>
      void setSide (char side);

      /// <summary>Sets price.</summary>
      /// <param name="price">Price.</param>
      void setPrice (double price);

      /// <summary>Sets symbol code.</summary>
      /// <param name="symbol">Symbol code.</param>
      void setSymbol (char *symbol);

      /// <summary>Sets exchange code.</summary>
      /// <param name="exchange">Exchange code.</param>
      void setExchange (char *exchange);

    private:
      OTBBO (const OTBBO &);
      OTBBO & operator = (const OTBBO &);

      int    requestId;
      int    timestamp;
      int    size;
      char   side;
      char  *symbol;
      char   exchange[3];
      double price;
  };


#endif
