/** \file OTBookCancel.h
*   \brief OTBookCancel class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BOOK_CANCEL_H
#define _OT_BOOK_CANCEL_H

#include "OTDef.h"
  
  /// <summary>
  /// This is a change to an existing order. 
  /// Look up the existing order using the order reference, and subtract the size. 
  /// If the order now has no shares, remove the order.
  /// </summary>
  class   OTBookCancel 
  {
    public:
      /// <summary> Default constructor. </summary>
      OTBookCancel();

      /// <summary> Destructor. </summary>
      ~OTBookCancel();

      /// <returns>ID of the appropriate request.</returns>
      int   getRequestId();

      /// <returns>Time when the event occurred.</returns>
      int   getTimestamp();

      /// <returns>Number of shares.</returns>
      int   getSize();

      /// <returns>Order reference.</returns>
      char *getOrderRef();

      /// <summary>Sets ID of appropriate request.</summary>
      /// <param name="requestId">ID of appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>Sets number of shares.</summary>
      /// <param name="size">Number of shares.</param>
      void setSize (int size);

      /// <summary>Sets order reference.</summary>
      /// <param name="orderRef">Order reference.</param>
      void setOrderRef (char *orderRef);
      
    private:
      OTBookCancel (const OTBookCancel &);
      OTBookCancel & operator = (const OTBookCancel &);

      int   requestId;
      int   timestamp;
      int   size;
      char *orderRef;
  };


#endif
