/** \file OTBookChange.h
*   \brief OTBookChange class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BOOK_CHANGE_H
#define _OT_BOOK_CHANGE_H

#include "OTDef.h"
  
  /// <summary>Look up the order, and change its size.</summary>
  class   OTBookChange 
  {
    public:
      /// <summary> Default constructor. </summary>
      OTBookChange();

      /// <summary> Destructor. </summary>
      ~OTBookChange();

      /// <returns>ID of the appropriate request.</returns>
      int      getRequestId();

      /// <returns>Time when the event occurred.</returns>
      int      getTimestamp();

      /// <returns>Number of shares.</returns>
      int      getSize();

      /// <returns>Order reference.</returns>
      char    *getOrderRef();

      /// <returns>Price.</returns>
      double   getPrice();

      /// <summary>Sets ID of appropriate request.</summary>
      /// <param name="requestId">ID of appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>Sets number of shares.</summary>
      /// <param name="size">Number of shares.</param>
      void setSize (int size);      

      /// <summary>Sets order reference.</summary>
      /// <param name="orderRef">Order reference.</param>
      void setOrderRef (char *orderRef);

      /// <summary>Sets price.</summary>
      /// <param name="price">Price.</param>
      void setPrice (double price);

    private:
      OTBookChange (const OTBookChange &);
      OTBookChange & operator = (const OTBookChange &);

      int      requestId;
      int      timestamp;
      int      size;
      char    *orderRef;
      double   price;
  };


#endif
