/** \file OTBookDelete.h
*   \brief OTBookDelete class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BOOK_DELETE_H
#define _OT_BOOK_DELETE_H

#include "OTDef.h"
  
  /// <summary>
  /// Look up the order using the order reference, and delete orders depending on the Delete Type.
  /// </summary>
  class   OTBookDelete 
  {
    public:
      /// <summary> Default constructor. </summary>
      OTBookDelete();

      /// <summary> Destructor. </summary>
      ~OTBookDelete();

      /// <returns>ID of the appropriate request.</returns>
      int   getRequestId();

      /// <returns>Time when the event occurred.</returns>
      int   getTimestamp();

      /// <returns>Side: B = Buy, S = Sell.</returns>
      char  getSide();

      /// <returns>Order = 1, Previous = 2, All = 3, After = A</returns>
      char  getDeleteType();

      /// <returns>Order reference.</returns>
      char *getOrderRef();

      /// <summary>Sets ID of appropriate request.</summary>
      /// <param name="requestId">ID of appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>Sets side: B = Buy, S = Sell.</summary>
      /// <param name="side">Side: B = Buy, S = Sell.</param>
      void setSide (char side);

      /// <summary>Sets delete type.</summary>
      /// <param name="deleteType">Order = 1, Previous = 2, All = 3, After = A</param>
      void setDeleteType (char deleteType);      

      /// <summary>Sets order reference.</summary>
      /// <param name="orderRef">Order reference.</param>
      void setOrderRef (char *orderRef);
            
    private:
      OTBookDelete (const OTBookDelete &);
      OTBookDelete & operator = (const OTBookDelete &);

      int   requestId;
      int   timestamp;
      char  side;
      char  deleteType;
      char *orderRef;
  };


#endif
