/** \file OTBookExecute.h
*   \brief OTBookExecute class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BOOK_EXECUTE_H
#define _OT_BOOK_EXECUTE_H

#include "OTDef.h"
  
  /// <summary>
  /// This is a change to an existing order, and implies that a trade occurred. 
  /// Look up the existing order using the order reference, and subtract the size from the order. 
  /// If the order now has no shares, remove the order.
  /// </summary>
  class   OTBookExecute
  {
    public:
      /// <summary> Default constructor. </summary>
      OTBookExecute();

      /// <summary> Destructor. </summary>
      ~OTBookExecute();

      /// <returns>ID of the appropriate request.</returns>      
      int   getRequestId();

      /// <returns>Time when the event occurred.</returns>
      int   getTimestamp();

      /// <returns>Number of shares.</returns>
      int   getSize();

      /// <returns>ISLD specific unique match identifier.</returns>
      int   getMatchNumber();

      /// <returns>Order reference.</returns>
      char *getOrderRef();

      /// <summary>Sets ID of appropriate request.</summary>
      /// <param name="requestId">ID of appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>Sets number of shares.</summary>
      /// <param name="size">Number of shares.</param>
      void setSize (int size);      

      /// <summary>Sets ISLD specific unique match identifier.</summary>
      /// <param name="matchNumber">ISLD specific unique match identifier.</param>
      void setMatchNumber(int matchNumber);

      /// <summary>Sets order reference.</summary>
      /// <param name="orderRef">Order reference.</param>
      void setOrderRef (char *orderRef);

    private:
      OTBookExecute (const OTBookExecute &);
      OTBookExecute & operator = (const OTBookExecute &);

      int   requestId;
      int   timestamp;
      int   size;
      int   matchNumber;
      char *orderRef;
  };


#endif
