/** \file OTBookOrder.h
*   \brief OTBookOrder class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BOOK_ORDER_H
#define _OT_BOOK_ORDER_H

#include "OTDef.h"
  

  /// <summary>
  /// A new order. A record of the order should be created and indexed with the order reference.
  /// </summary>
  class   OTBookOrder 
  {
    public:
      /// <summary> Default constructor. </summary>
      OTBookOrder();

      /// <summary> Destructor. </summary>
      ~OTBookOrder();

      /// <returns>ID of the appropriate request.</returns>
      int     getRequestId();

      /// <returns>Time when the event occurred.</returns>
      int     getTimestamp();

      /// <returns>Order size in number of shares.</returns>
      int     getSize();      

      /// <returns>Order reference; identifies the order for subsequent events.</returns>
      char   *getOrderRef();      

      /// <returns>Side: B = Buy, S = Sell.</returns>
      char    getSide();

      /// <returns>Display.</returns>
      bool    getDisplay();      

      /// <returns>Price.</returns>
      double  getPrice();

      /// <summary>
      /// Sets ID of the appropriate request.
      /// </summary>
      /// <param name="requestId">ID of the appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>
      /// Sets order size in number of shares.
      /// </summary>
      /// <param name="size">Order size in number of shares.</param>
      void setSize (int size);      

      /// <summary>
      /// Sets order reference.
      /// </summary>
      /// <param name="orderRef">Order reference.</param>
      void setOrderRef (char *orderRef);

      /// <summary>
      /// Sets side: B = Buy, S = Sell.
      /// </summary>
      /// <param name="side">Side: B = Buy, S = Sell.</param>
      void setSide (char side);

      /// <summary>
      /// Sets display.
      /// </summary>
      /// <param name="display">Display.</param>
      void setDisplay (bool display);      

      /// <summary>
      /// Sets price.
      /// </summary>
      /// <param name="price">Price.</param>
      void setPrice (double price);

    private:
      OTBookOrder (const OTBookOrder &);
      OTBookOrder & operator = (const OTBookOrder &);

      int     requestId;
      int     timestamp;
      int     size;      
      char   *orderRef;
      char    side;
      bool    display;      
      double  price;
  };


#endif
