/** \file OTBookPriceLevel.h
*   \brief OTBookPriceLevel class definition.
*                               
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BOOK_PRICELEVEL_H
#define _OT_BOOK_PRICELEVEL_H

#include "OTDef.h"
  
  /// <summary>
  /// A book price level is the processed output of a bookServer. 
  /// The bookServer maintains the depth of book for ECN data, keeping track of each order. 
  /// In the bookServer orders of the same price are consolidated into price levels, 
  /// and a Book Price Level message is issued whenever the size of a price level changes. 
  /// Even though we maintain the book on all orders only the top book levels are sent as Book Price Level events. 
  /// Typically the top six levels are sent for both the buy and sell sides.
  /// </summary>
  class   OTBookPriceLevel 
  {
    public:
      /// <summary> Default constructor. </summary>
      OTBookPriceLevel();

      /// <summary> Destructor. </summary>
      ~OTBookPriceLevel();

      /// <returns>ID of the appropriate request.</returns>
      int     getRequestId();

      /// <returns>Time when the event occurred.</returns>
      int     getTimestamp();

      /// <returns>Number of shares.</returns>
      int     getSize();      

      /// <returns>Unique level identifier.</returns>
      char   *getLevelId();

      /// <returns>Side: B = Bid, S = Sell.</returns>
      char    getSide();      

      /// <returns>Price.</returns>
      double  getPrice();

      /// <summary>
      /// Sets ID of the appropriate request.
      /// </summary>
      /// <param name="requestId">ID of the appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>
      /// Sets number of shares.
      /// </summary>
      /// <param name="size">Number of shares.</param>
      void setSize (int size);      

      /// <summary>
      /// Sets unique level identifier.
      /// </summary>
      /// <param name="levelId">Unique level identifier.</param>
      void setLevelId (char *levelId);

      /// <summary>
      /// Sets side: B = Bid, S = Sell.
      /// </summary>
      /// <param name="side">Side: B = Bid, S = Sell.</param>
      void setSide (char side);

      /// <summary>
      /// Sets price.
      /// </summary>
      /// <param name="price">Price.</param>
      void setPrice (double price);

    private:
      OTBookPriceLevel (const OTBookPriceLevel &);
      OTBookPriceLevel & operator = (const OTBookPriceLevel &);

      int     requestId;
      int     timestamp;
      int     size;
      char   *levelId;
      char    side;
      double  price;
  };


#endif
