/** \file OTBookReplace.h
*   \brief OTBookReplace class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_BOOK_REPLACE_H
#define _OT_BOOK_REPLACE_H

#include "OTDef.h"
  
  /// <summary>
  /// Look up the order, and change its size. If the order is not there, create it, setting the symbol price and size.
  /// </summary>
  class   OTBookReplace 
  {
    public:
      /// <summary>
      /// 
      /// </summary>
      OTBookReplace();

      /// <summary>
      /// 
      /// </summary>
      ~OTBookReplace();

      /// <returns>ID of the appropriate request.</returns>
      int     getRequestId();

      /// <returns>Time when the event occurred.</returns>
      int     getTimestamp();

      /// <returns>Number of shares.</returns>
      int     getSize();      

      /// <returns>Order reference; identifies the order for subsequent events.</returns>
      char   *getOrderRef();

      /// <returns>Side: B = Buy, S = Sell.</returns>
      char    getSide();      

      /// <returns>Price.</returns>
      double  getPrice();

      /// <summary>
      /// Sets ID of the appropriate request.
      /// </summary>
      /// <param name="requestId">ID of the appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>Sets time of the event.</summary>
      /// <param name="timestamp">Time when the event occurred.</param>
      void setTimestamp (int timestamp);

      /// <summary>
      /// Sets number of shares.
      /// </summary>
      /// <param name="size">Number of shares.</param>
      void setSize (int size);  

      /// <summary>
      /// Sets Order reference.
      /// </summary>
      /// <param name="orderRef">Order reference.</param>
      void setOrderRef (char *orderRef);

      /// <summary>
      /// Sets side: B = Buy, S = Sell.
      /// </summary>
      /// <param name="side">Side: B = Buy, S = Sell.</param>
      void setSide (char side);    

      /// <summary>
      /// Sets price.
      /// </summary>
      /// <param name="price">Price.</param>
      void setPrice (double price);

    private:
      OTBookReplace (const OTBookReplace &);
      OTBookReplace & operator = (const OTBookReplace &);

      int     requestId;
      int     timestamp;
      int     size;
      char   *orderRef;
      char    side;                
      double  price;
  };


#endif
