/** \file OTConst.h                                         
*   \brief Definition of opentick constants.
*   Copyright (C) 2004 Opentick corporation. All rights reserved.
*/


#ifndef _OT_CONST_H
#define _OT_CONST_H

/** @defgroup constants OTFeed API Constants
 *  Constants that were used in API.
 *  @{
 */

/** API states */

/** API state: the client is inactive */
#define OT_STATUS_INACTIVE       1 

/** API state: the client is trying to connect */
#define OT_STATUS_CONNECTING     2

/** API state: the client is connected, but still not logged in */
#define OT_STATUS_CONNECTED      3

/** API state: the client is logged in */
#define OT_STATUS_LOGGED_IN      4



/** Message codes */

/** End of data */
#define OT_MSG_END_OF_DATA       10

/** Confirmation of the cancel command */
#define OT_MSG_END_OF_REQUEST    20

/** End of snapshot data */
#define OT_MSG_END_OF_SNAPSHOT   30



/** Instrument types */

/** Stock */
#define  OT_INSTRUMENT_STOCK     1

/** Index */
#define  OT_INSTRUMENT_INDEX     2

/** Option */
#define  OT_INSTRUMENT_OPTION    3

/** Future */
#define  OT_INSTRUMENT_FUTURE    4


/** Historical data types */

/** Raw ticks */
#define OT_HIST_RAW_TICKS         1

/** Tick-based OHLC values */
#define OT_HIST_OHLC_TICK_BASED   2

/** Minutely OHLC values */
#define OT_HIST_OHLC_MINUTELY     3

/** Hourly OHLC values */
#define OT_HIST_OHLC_HOURLY       4

/** Daily OHLC values */
#define OT_HIST_OHLC_DAILY        5

/** Weekly OHLC values */
#define OT_HIST_OHLC_WEEKLY       6

/** Monthly OHLC values */
#define OT_HIST_OHLC_MONTHLY      7

/** Yearly OHLC values */
#define OT_HIST_OHLC_YEARLY       8

/** Books */
#define OT_HIST_BOOKS             9

/** List Symbols */
#define OT_LIST_SYMBOLS           10

/** Error types */

/** opentick error */
#define OT_ERR_OPENTICK      1000     

/** System error */
#define OT_ERR_SYSTEM        2000

/** Network error */
#define OT_ERR_SOCK          3000



/** Error codes */

/** Incorrect login */
#define OT_ERR_INCORRECT_LOGIN     1001   

/** You are not logged in */
#define OT_ERR_NOT_LOGGED_IN       1002   

/** Requested data does not exist */
#define OT_ERR_NO_DATA             1003   

/** Invalid cancelId */
#define OT_ERR_INVALID_CANCEL_ID   1004   

/** Invalid interval type or value
*   of the request for historical data
*/
#define OT_ERR_INVALID_INTERVAL    1005   

/** You do not have a license to
*   request real-time data from the
*   specified exchange
*/
#define OT_ERR_NO_LICENSE          1006   

/** Your symbol limit is exceeded */
#define OT_ERR_LIMIT_EXCEEDED      1007   

/** You have requested this
*   tick stream already
*/
#define OT_ERR_DUPLICATE_REQUEST   1008   

/** Your account is inactive */
#define OT_ERR_INACTIVE_ACCOUNT    1009   

/** You are logged in already */
#define OT_ERR_LOGGED_IN           1010

/** Parameters of the request
*   are incorrect
*/
#define OT_ERR_BAD_REQUEST         1011

/** You are not subscribed to
*   a historical data package
*/
#define OT_ERR_NO_HIST_PACKAGE     1012

/** You made maximally possible
*   count of historical requests
*/
#define OT_ERR_MAX_HIST_REQUESTS   1013


/** Cannot initialize WinSockets library */
#define OT_ERR_NO_SOCKETS_DLL      2001

/** Server error */
#define OT_ERR_SERVER_ERROR        2002

/** Cannot connect to the server */
#define OT_ERR_CANNOT_CONNECT      2003

/** The connection has been broken */
#define OT_ERR_BROKEN_CONNECTION   2004

/** Cannot create thread */
#define OT_ERR_NO_THREAD           2005
                                 
/** Cannot initialize socket */
#define OT_ERR_NO_SOCKET           2006

////** Receive error */
///#define OT_ERR_RECEIVE             2007

/** Bits of the option chain or option init params mask */

/** without date and prices */
#define OT_OPTION_NONE    0 

/** with date but without prices */
#define OT_OPTION_DATE    1 

/** with prices but without date */
#define OT_OPTION_PRICE   2 

/** with date and prices */
#define OT_OPTION_FULL    (OT_OPTION_DATE|OT_OPTION_PRICE) 

/** Bits of the tick stream or option chain request mask */

/** Quote */
#define OT_TICK_TYPE_QUOTE    1

/** MMQuote */
#define OT_TICK_TYPE_MMQUOTE  2

/** Trade */
#define OT_TICK_TYPE_TRADE    4

/** BBO */
#define OT_TICK_TYPE_BBO      8

/** Level1 data */
#define OT_TICK_TYPE_LEVEL1   (OT_TICK_TYPE_QUOTE|OT_TICK_TYPE_TRADE|OT_TICK_TYPE_BBO)

/** Level2 data */
#define OT_TICK_TYPE_LEVEL2   OT_TICK_TYPE_MMQUOTE

/** Both levels data */
#define OT_TICK_TYPE_BOTH     (OT_TICK_TYPE_LEVEL1|OT_TICK_TYPE_LEVEL2)

/** All data */
#define OT_TICK_TYPE_ALL      OT_TICK_TYPE_BOTH

/** Bits of the books request mask */

/** Book Cancel events */
#define OT_BOOK_TYPE_CANCEL       16
/** Book Change events */
#define OT_BOOK_TYPE_CHANGE       32
/** Book Delete events */
#define OT_BOOK_TYPE_DELETE       64
/** Book Execute events */
#define OT_BOOK_TYPE_EXECUTE      128
/** Book Order events */
#define OT_BOOK_TYPE_ORDER        256
/** Book Price Level events */
#define OT_BOOK_TYPE_PRICE_LEVEL  512
/** Book Purge events */
#define OT_BOOK_TYPE_PURGE        1024
/** Book Replace events */
#define OT_BOOK_TYPE_REPLACE      2048
/** All book events */
#define OT_BOOK_TYPE_ALL          (OT_BOOK_TYPE_CANCEL|OT_BOOK_TYPE_CHANGE|OT_BOOK_TYPE_DELETE|OT_BOOK_TYPE_EXECUTE|OT_BOOK_TYPE_ORDER|OT_BOOK_TYPE_PRICE_LEVEL|OT_BOOK_TYPE_PURGE|OT_BOOK_TYPE_REPLACE) 

/** Volume type mask bit (24th bit: 0 - consolidated; 1 - individual) */
/** Individual volume*/
#define OT_VOLUME_TYPE_INDIVIDUAL 16777216
/** Consolidated volume*/
#define OT_VOLUME_TYPE_CONSOLIDATED 0

/** List symbols request mask.
 *  Types (bits) of equities (you can combine them using "|" operator).
 */

/** Stock */
#define OT_LIST_SYMBOLS_STOCK       1
/** Index */
#define OT_LIST_SYMBOLS_INDEX       2
/** Option */
#define OT_LIST_SYMBOLS_OPTION      4
/** Future */
#define OT_LIST_SYMBOLS_FUTURE      8
/** SSFuture */
#define OT_LIST_SYMBOLS_SSFUTURE    16
/** Top ten*/
#define OT_LIST_SYMBOLS_TOP_TEN     32
/** All types*/
#define OT_LIST_SYMBOLS_ALL_TYPES   (OT_LIST_SYMBOLS_STOCK| OT_LIST_SYMBOLS_INDEX| OT_LIST_SYMBOLS_OPTION| OT_LIST_SYMBOLS_FUTURE| OT_LIST_SYMBOLS_SSFUTURE| OT_LIST_SYMBOLS_TOP_TEN)

/** Kind of name usage
 * (only one could be specified)
  */
#define OT_LIST_SYMBOLS_STARTSWITH  0
#define OT_LIST_SYMBOLS_CONTAINS    0x20000

/** @} */
#endif
