/** \file OTDataEntity.h
*   \brief OTDataEntity class definition.
*
*   Copyright (C) 2004 Opentick corporation. All rights reserved.
*/

#ifndef _OT_DATA_ENTITY_H
#define _OT_DATA_ENTITY_H

#include "OTDef.h"

  /// <summary>
  /// This class represents the market data entity or financial 
  /// instrument you are requesting data for. This instantiated 
  /// class is a required argument for most request types. The exchange
  /// argument is either an opentick exchange code or product code. The
  /// symbol is the symbol you will be requesting data for on the specified exchange.
  /// </summary>
  class   OTDataEntity
  {
    public:
      /// <summary> Default constructor. </summary>
      OTDataEntity();

      /// <summary> Constructor. </summary>
      /// <param name="exchange"> Exchange code. </param>
      /// <param name="symbol"> Symbol code. </param>
      OTDataEntity (const char *exchange, const char *symbol);

      /// <summary> Copy constructor. </summary>  
      OTDataEntity (const OTDataEntity &);

      /// <summary> Assignment. </summary>  
      OTDataEntity & operator = (const OTDataEntity &);

      /// <summary> Destructor. </summary>
      ~OTDataEntity();

      /// <summary> Compares exchange and symbol codes. </summary>  
      /// <returns> True if exchange and symbol codes are the same </returns>
      bool operator == (OTDataEntity &entity);

      /// <returns> Pointer to the duplicated entity. </returns>
      OTDataEntity* clone();

      /// <returns> Exchange code </returns>
      char  *getExchange();
  
      /// <returns> Symbol code </returns>
      char  *getSymbol();

      /// <summary> Sets exchange code. </summary>
      void setExchange (char *exchange);

      /// <summary> Sets symbol code. </summary>
      /// <param name="symbol"> Symbol code. </param>
      void setSymbol (char *symbol);

      void store (char *);

    private:
      char  *exchange;
      char  *symbol;
  };

#endif
