/** \file OTSplit.h
*   \brief OTDividend class definition.
*
*   Copyright (C) 2004,2005,2006 Opentick corporation. All rights reserved.
*/

#ifndef _OT_DIVIDEND_H
#define _OT_DIVIDEND_H

#include "OTDef.h"


  /// <summary>
  /// This class provides OTDividend events and member functions to reference the
  /// data provided by the object.
  /// </summary>
  class   OTDividend 
  {
    public:
      /// <summary> Default constructor </summary>
      OTDividend();

      /// <summary> Destructor </summary>
      ~OTDividend();

       /// <returns>ID of the request which caused the message.</returns>
        int getRequestId();

       /// <returns> Dividend (value).</returns>
       double getPrice(); 

       /// <returns>Date of declaration.</returns>
       int getDeclarationDate();

       /// <returns>Date of execution.</returns>
       int getExecutionDate();

       /// <returns>Date of record.</returns>
       int getRecordDate();

       /// <returns>Date of payment.</returns>
       int getPaymentDate();

       bool isApproximate();
       bool isAnnual();
       bool isCanadian();
       bool isExtra();
       bool isFinal();
       bool isIncrease();
       bool isSemiannual();
       bool isStock(); 
       bool isSpecial(); 

       /// <summary>
       /// Sets ID of the appropriate request.
       /// </summary>
       /// <param name="requestId">ID of the appropriate request.</param>
       void setRequestId(int requestId);
   
       /// <summary>
       /// Sets dividend (value).
       /// </summary>
       /// <param name="price">Dividend (value).</param>
       void setPrice(double price);
   
       /// <summary>
       /// Sets isApproximate, isAnnual, isCanadian, isExtra, isFinal, isIncrease, isSemiannual, isStock flags,
       /// bits are in compliance with declaration.
       /// </summary>
       /// <param name="flags1">Flags values.</param>
       void setFlags1(unsigned char flags1);
   
       /// <summary>
       /// Sets isSpecial flag.
       /// </summary>
       /// <param name="flags2">Flags values.</param>
       void setFlags2(unsigned char flags2);
   
       /// <summary>
       /// Sets declaration date.
       /// </summary>
       /// <param name="declarationDate">Declaration date.</param>
       void setDeclarationDate(int declarationDate);
   
       /// <summary>
       /// Sets execution date.
       /// </summary>
       /// <param name="executionDate">Execution date.</param>
       void setExecutionDate(int executionDate);
   
       /// <summary>
       /// Sets record date.
       /// </summary>
       /// <param name="recordDate">Record date.</param>
       void setRecordDate(int recordDate);
   
       /// <summary>
       /// Sets payment date.
       /// </summary>
       /// <param name="paymentDate">Payment date.</param>
       void setPaymentDate(int paymentDate);

    private:
      OTDividend (const OTDividend &);
      OTDividend & operator = (const OTDividend &);
      
      int     requestId;
      unsigned char flags1;
      unsigned char flags2;
      double price;
      int declarationDate;
      int executionDate;
      int recordDate;
      int paymentDate;
  };


#endif
