/** \file OTError.h
*   \brief OTError class definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/

#ifndef _OT_ERROR_H
#define _OT_ERROR_H


#include "OTDef.h"


  /// <summary>
  /// This class provides error information.
  /// </summary>  
  class   OTError 
  {
    public:
      /// <summary> Default constructor. </summary>
      OTError();
    
      /// <summary> Destructor. </summary>
      ~OTError();

      /// <returns>
      /// ID of the request which caused the error. This value may be zero if this error is
      /// not connected with any of the request functions.
      /// </returns>
      int   getRequestId();

      /// <returns> Error type. </returns>
      int   getType();

      /// <returns> Error code. </returns>
      int   getCode();

      /// <returns> Description of the error. </returns>
      char *getDescription();
      
      /// <summary> Sets request ID. </summary>
      /// <param name="requestId">Request ID </param>
      void setRequestId (int requestId);

      /// <summary> Sets error type. </summary>
      /// <param name="type"> Error type. </param>
      void setType (int type);

      /// <summary> Sets error code. </summary>
      /// <param name="code"> Error code. </param>
      void setCode (int code);

      /// <summary> Sets description of the error. </summary>
      /// <param name="description"> Description of the error. </param>
      void setDescription (char *description);

    private:
      OTError (const OTError &);
      OTError & operator = (const OTError &);

      int   requestId;
      int   type;
      int   code;
      char *description;
  };


#endif
