/** \file OTExchange.h
*   \brief OTExchange class definition.
*
*   Copyright (C) 2004 Opentick corporation. All rights reserved.
*/

#ifndef _OT_EXCHANGE_H
#define _OT_EXCHANGE_H


#include "OTDef.h"


  
  /// <summary>
  /// Provides exchange information.
  /// </summary>
  class   OTExchange 
  {
    public:
      /// <summary> Default constructor </summary>
      OTExchange();

      /// <summary> Destructor </summary>
      ~OTExchange();

      /// <returns>ID of the request which caused the message.</returns>
      int   getRequestId();      

      /// <returns> The exchange code. </returns>
      char *getCode();

      /// <returns> The exchange title. </returns>
      char *getTitle();

      /// <returns> A description of the exchange. </returns>
      char *getDescription();

      /// <returns>
      /// If the user is not subscribed to this exchange, he can go to this URL to do so.
      /// </returns>
      char *getSubscriptionURL();

      /// <returns>
      /// Shows whether the user has a license to request real-time 
      /// data from this exchange.
      /// </returns>
      bool  getAvailable(); 
      

      /// <summary>
      /// Sets ID of the appropriate request.
      /// </summary>
      /// <param name="requestId">ID of the appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>
      /// Sets available field.
      /// </summary>
      /// <param name="available">Available field.</param>
      void setAvailable (bool available);

      /// <summary>
      /// Sets exchange code.
      /// </summary>
      /// <param name="code">Exchange code.</param>
      void setCode (const char *code);

      /// <summary>
      /// Sets exchange title.
      /// </summary>
      /// <param name="title">Exchange title.</param>
      void setTitle (const char *title);

      /// <summary>
      /// Sets description of the exchange.
      /// </summary>
      /// <param name="description">Description of the exchange.</param>
      void setDescription (const char *description);

      /// <summary>
      /// Sets SubscriptionURL field.
      /// </summary>
      /// <param name="URL">URL</param>
      void setSubscriptionURL (const char *URL);

    private:
      OTExchange (const OTExchange &);
      OTExchange & operator = (const OTExchange &);
     
      char  *URL;
      char  *code;
      char  *title;
      char  *description;
      bool   available;
      int    requestId;    
  };


#endif
