#ifndef _OT_OPTIONINIT_H
#define _OT_OPTIONINIT_H
 
#include "OTDef.h"

/// <summary>
/// This class provides an Option Initialize event and member functions to
/// reference the data returned.
/// </summary>
class   OTOptionInit
{
  public:
    /// <summary> Default constructor </summary>
    OTOptionInit(); 

    /// <summary> Destructor </summary>
    ~OTOptionInit();

    /// <returns>ID of the request which caused the message.</returns>
    int     getRequestId();

    /// <returns>Underlying symbol name.</returns>
    char   *getUnderlyerSymbol();

    /// <returns>Symbol name for the option.</returns>
    char   *getSymbol();

    /// <returns>Strike price for the option.</returns>
    double  getStrikePrice();

    /// <returns>Contract size.</returns>
    int     getContractSize();

    /// <returns>Expiration year.</returns>
    char   *getExpYear();

    /// <returns>Expiration month.</returns>
    char   *getExpMonth();

    /// <returns>Expiration day.</returns>
    char   *getExpDay();

    /// <returns>"A" = American, "E" = European, "C" = Capped.</returns>
    char    getExerciseStyle();

    /// <returns>CUSIP ID for the underlying symbol.</returns>
    char   *getUnderlyerCusip();

    /// <returns>Currency type used.</returns>
    char   *getCurrency();

    /// <returns>(Montreal only).</returns>
    char    getOptionMarker();


    void setRequestId(int requestId);
    void setUnderlyerSymbol(char *underlyerSymbol);
    void setSymbol(char *symbol);
    void setStrikePrice(double strikePrice);
    void setContractSize(int contractSize);
    void setExpYear(char *expYear);
    void setExpMonth(char *expMonth);
    void setExpDay(char *expDay);
    void setExerciseStyle(char exerciseStyle);
    void setUnderlyerCusip(char *underlyerCusip);
    void setCurrency(char *currency);
    void setOptionMarker(char optionMarker);

  private: 
    int     requestId;
    char   *underlyerSymbol;
    char   *symbol;
    double  strikePrice;
    int     contractSize;
    char    expYear[5];
    char    expMonth[3];
    char    expDay[3];
    char    exerciseStyle;
    char   *underlyerCusip;
    char    currency[4];
    char    optionMarker;
};

#endif
