/** \file OTResponse.h
*   \brief Response and QueueResponse classes implementation
*   These classes were designed to store OTP responses of the server.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/


#ifndef _OT_RESPONSE_H
#define _OT_RESPONSE_H

#include <queue>


  /** This class is used to store OT response of the server.
  */
  class Response 
  {
    public:
      char *data;   // response
      int length;   // length

      /** Response constructor.\n
      *   Used to copy pointer to the response string, and length of the string.
      *   \param data (input)   - response string;
      *   \param length (input) - length of the response;
      */
      Response (char *data, int length) 
      {
        this->data = data;
        this->length = length;
      }

      /** Response destructor.\n
      *   Used to free memory used by the response string;
      */
      ~Response () 
      {
        delete [] data; 
      }
  };


  /** This class is used to store pointers to objects of the Response type 
  *   in the standard queue container.
  */
  class QueueResponse : public std::queue <Response *> 
  {
    public:

      /** This function is used to empty the queue.
        \return none.
      */
      virtual void clear () 
      {
        while (! empty()) 
        {
          Response *resp = front();
          pop();
          delete resp;
        }
      }

      /** QueueResponse destructor. Calls QueueResponse::clear().
      */
      virtual ~QueueResponse () 
      {
        clear();
      }
  };


#endif
