/** \file OTSplit.h
*   \brief OTSplit class definition.
*
*   Copyright (C) 2004,2005,2006 Opentick corporation. All rights reserved.
*/

#ifndef _OT_SPLIT_H
#define _OT_SPLIT_H

#include "OTDef.h"


  /// <summary>
  /// This class provides OTSplit events and member functions to reference data
  ///  provided by the object.
  /// </summary>
  class   OTSplit 
  {
    public:
      /// <summary> Default constructor </summary>
      OTSplit();

      /// <summary> Destructor </summary>
      ~OTSplit();

       /// <returns>ID of the request which caused the message.</returns>
       int getRequestId();
 
       /// <returns>To factor.</returns>
       int getToFactor();
 
       /// <returns>For factor.</returns>
       int getForFactor();
 
       /// <returns>Declaration date.</returns>
       int getDeclarationDate();
 
       /// <returns>Execution date.</returns>
       int getExecutionDate();
 
       /// <returns>Record date.</returns>
       int getRecordDate();
 
       /// <returns>Payment date.</returns>
       int getPaymentDate();

       /// <summary>
       /// Sets ID of the appropriate request.
       /// </summary>
       /// <param name="requestId">ID of the appropriate request.</param>
       void setRequestId(int requestId);

       /// <summary>
       /// Sets to factor.
       /// </summary>
       /// <param name="toFactor">To factor.</param>
       void setToFactor(int toFactor);

       /// <summary>
       /// Sets for factor.
       /// </summary>
       /// <param name="forFactor">For factor.</param>
       void setForFactor(int forFactor);

       /// <summary>
       /// Sets declaration date.
       /// </summary>
       /// <param name="declarationDate">Declaration date.</param>
       void setDeclarationDate(int declarationDate);

       /// <summary>
       /// Sets execution date.
       /// </summary>
       /// <param name="executionDate">Execution date.</param>
       void setExecutionDate(int executionDate);

       /// <summary>
       /// Sets record date.
       /// </summary>
       /// <param name="recordDate">Record date.</param>
       void setRecordDate(int recordDate);

       /// <summary>
       /// Sets payment date.
       /// </summary>
       /// <param name="paymentDate">Payment date.</param>
       void setPaymentDate(int paymentDate);

    private:
      OTSplit (const OTSplit &);
      OTSplit & operator = (const OTSplit &);
      
      int    requestId;
      int    toFactor;
      int    forFactor;
      int    declarationDate;
      int    executionDate;
      int    recordDate;
      int    paymentDate;
  };


#endif
