#ifndef _OT_STRUCT_H
#define _OT_STRUCT_H


#define OT_LIBRARY_VER 4

/** Platform identifiers */
#define OT_PLATFORM_OT           1
#define OT_PLATFORM_QUANTSTUDIO  2
#define OT_PLATFORM_WEALTHLAB    3
#define OT_PLATFORM_FIRST_LANG   OT_PLATFORM_CPP
#define OT_PLATFORM_CPP          4
#define OT_PLATFORM_PERL         5
#define OT_PLATFORM_COM          6
#define OT_PLATFORM_JAVA         7
#define OT_PLATFORM_DOTNET       8
#define OT_PLATFORM_LAST_LANG    OT_PLATFORM_DOTNET

#define SESSION_ID_LEN     64
#define USERNAME_LEN       64
#define PASSWORD_LEN       64
#define HOST_NAME_LEN      64

#define EXCHANGE_CODE_LEN       15
#define SYMBOL_CODE_LEN         15
#define CURRENCY_CODE_LEN       4
#define PLATFORM_ID_PWD_LEN     16
#define MAC_ID_LEN              6

#define DAY_SECONDS             86400
#define WEEK_SECONDS            604800  

#define TICK_BLOCK_SIZE         41
#define OHLC_BLOCK_SIZE         57
#define OHLC_DAILY_BLOCK_SIZE   53
#define EQUITY_INIT_BLOCK_SIZE  194

#define OT_OS_UNKNOWN  1
#define OT_OS_WIN95    2
#define OT_OS_WIN98    3
#define OT_OS_WIN98SE  4
#define OT_OS_WINME    5
#define OT_OS_WINNT    6
#define OT_OS_WIN2000  7
#define OT_OS_WINXP    8 
#define OT_OS_LINUX    20


#define OT_MSG_CLIENT_REQUEST     1
#define OT_MSG_SERVER_RESPONSE    2

#define OT_COMMAND_STATUS_OK      1
#define OT_COMMAND_STATUS_ERROR   2

#define OT_EXCHANGE_AVAIL     1
#define OT_EXCHANGE_UNAVAIL   2


// OTP command codes
#define OTP_INT_UNKNOWN               0
#define OT_LOGIN                      1
#define OT_LOGOUT                     2
#define OT_REQUEST_TICK_STREAM        3
#define OT_REQUEST_TICK_STREAM_EX     15
#define OT_CANCEL_TICK_STREAM         4
#define OT_REQUEST_HIST_DATA          5
#define OT_REQUEST_HIST_TICKS         17
#define OT_CANCEL_HIST_DATA           6
#define OT_REQUEST_LIST_EXCHANGES     7
#define OT_REQUEST_LIST_SYMBOLS       8
#define OT_HEARTBEAT                  9
#define OT_REQUEST_EQUITY_INIT        10
#define OT_REQUEST_OPTION_CHAIN       11
#define OT_REQUEST_OPTION_CHAIN_EX    16
#define OT_CANCEL_OPTION_CHAIN        12
#define OT_REQUEST_BOOK_STREAM        13
#define OT_CANCEL_BOOK_STREAM         14
#define OT_REQUEST_SPLITS             18
#define OT_REQUEST_DIVIDENDS          19
#define OT_REQUEST_HIST_BOOKS         20 
#define OT_REQUEST_BOOK_STREAM_EX     21
#define OT_REQUEST_OPTION_CHAIN_U     22
#define OT_REQUEST_OPTION_INIT        23
#define OT_REQUEST_LIST_SYMBOLS_EX    24
#define OT_REQUEST_TICK_SNAPSHOT      25
#define OT_REQUEST_OPTION_CHAIN_SNAPSHOT 26

#define OT_HIST_OHL_TODAY           9


// types of statistical data
#define OT_STATS_TRAFFIC_OVERHEAD           0
#define OT_STATS_TRAFFIC_TICKS              1
#define OT_STATS_TRAFFIC_HIST_TICKS         2
#define OT_STATS_TRAFFIC_HIST_OHLC          3


// max filename length
#define MAX_FILENAME_LEN      256

  /**Structure that used in OTP protocol implementation.*/
  typedef struct
  {
    char  messageType;
    char  commandStatus;
    int   commandType;
    int   requestId;
  } 
  OTHeader_t;

  /**Structure that used in OTP protocol implementation.*/
  typedef struct 
  {
    short version;
    char  osId;
    char  platformId;
    char  platformIdPwd [PLATFORM_ID_PWD_LEN];   
    char  macId [MAC_ID_LEN];
    char  username [USERNAME_LEN];
    char  password [PASSWORD_LEN];
  } 
  OTLoginRequest_t;

  /**Structure that used in OTP protocol implementation.*/
  typedef struct 
  {
    char  sessionID [SESSION_ID_LEN];
  } 
  OTLoginResponse_t;


  /**Structure that used in OTP protocol implementation.*/
  typedef struct 
  {
    char  sessionID [SESSION_ID_LEN];
  } 
  OTLogoutRequest_t;


  /**Structure that used in OTP protocol implementation.*/
  typedef struct 
  {
    char  sessionID [SESSION_ID_LEN];
    char  exchangeCode [EXCHANGE_CODE_LEN];
    char  symbolCode [SYMBOL_CODE_LEN];
  } 
  OTRequestTickStreamRequest_t;

  typedef struct : OTRequestTickStreamRequest_t
  {
    int mask;
  }OTRequestTickStreamExRequest_t;

  #define OTRequestEquityInitRequest_t OTRequestTickStreamRequest_t
  #define OTRequestOptionChainRequest_t OTRequestTickStreamRequest_t
  #define OTRequestBookStreamRequest_t OTRequestTickStreamRequest_t
  #define OTRequestBookStreamExRequest_t OTRequestTickStreamExRequest_t

  #pragma pack(push,1)
  typedef struct
  {
    char  sessionID [SESSION_ID_LEN];
    char  exchangeCode [EXCHANGE_CODE_LEN];
    char  symbolCode [SYMBOL_CODE_LEN];
    int   startingDate;
    int   endingDate;
  }OTRequestSplitRequest_t;
  #pragma pack(pop)

  #define OTRequestDividendRequest_t OTRequestSplitRequest_t
  /**Structure that used in OTP protocol implementation.*/
  typedef struct 
  {
    double  openPrice;
    double  highPrice;
    double  lowPrice;
    double  closePrice;
    int     volume;
  } 
  OTOhlcData_t;


  /**Structure that used in OTP protocol implementation.*/
  typedef struct 
  {
    char  sessionID [SESSION_ID_LEN];
    int   cancelID;
  } 
  OTCancel_t;


  /**Structure that used in OTP protocol implementation.*/
  #pragma pack(push,4)
  typedef struct 
  {
    char   sessionID [SESSION_ID_LEN];
    char   exchangeCode [EXCHANGE_CODE_LEN];
    char   symbolCode [SYMBOL_CODE_LEN];
    int    startingDate;
    int    endingDate;
    char   dataType;
    short  intervalValue;
  } 
  OTRequestHistDataRequest_t;
  #pragma pack(pop)


  #define LEN_LOGIN                 154
  #define LEN_HEADER                10
  #define LEN_CANCEL                68
  #define LEN_REQUEST_TICK_STREAM   94
  #define LEN_REQUEST_HIST_DATA     105


  // ---------------------------------------------------------------------------
  /**Buffer and its length */
  class MemStruct
  {
    public:
      MemStruct (char *buf, int len)
      {
        this->buf = buf;
        this->len = len;
      }

      void setBuf (char *buf)
      {
        this->buf = buf;
      }

      void clear()
      {
        memset (buf, 0, len);
      }
    
    protected:
      char  *buf;
      int    len;
  };


  // ---------------------------------------------------------------------------
  /**Class that gives interpretation of the char buffer. 
   *
   * It supposes that buffer has OTHeader_t structure.
   */
  class StructHeader: public MemStruct
  {
    public:
      StructHeader (char *buf): MemStruct (buf, LEN_HEADER)
      {
      }

      // messageType
      char getMessageType()
      {
        return *buf;
      }

      void setMessageType (char val)
      {
        *buf = val;
      }

      // commandType
      int getCommandType()
      {
        return *(int*)(buf + 1);
      }

      void setCommandType (int val)
      {
        *(int*)(buf + 1) = val;
      }

      // commandStatus
      char getCommandStatus()
      {
        return *(buf + 5);
      }

      void setCommandStatus (char val)
      {
        *(buf + 5) = val;
      }

      // requestId
      int getRequestId()
      {
        return *(int*)(buf + 6);
      }

      void setRequestId (int val)
      {
        *(int*)(buf + 6) = val;
      }
  };


  // ---------------------------------------------------------------------------
  /**Class that gives interpretation of the char buffer. 
   *
   * It supposes that buffer has OTCancel_t structure.
   */
  class StructCancel: public MemStruct
  {
    public:
      StructCancel (char *buf): MemStruct (buf, LEN_CANCEL)
      {
      }

      // sessionId
      char *getSessionId()
      {
        return buf;
      }

      void setSessionId (char *val)
      {
        memcpy (buf, val, SESSION_ID_LEN);
      }

      // cancelId
      int getCancelId()
      {
        return *(int*)(buf + SESSION_ID_LEN);
      }

      void setCancelId (int val)
      {
        *(int*)(buf + SESSION_ID_LEN) = val;
      }
  };

  
  // ---------------------------------------------------------------------------
  /**Class that gives interpretation of the char buffer. 
   *
   * It supposes that buffer has OTLoginRequest_t structure.
   */
  class StructLogin: public MemStruct
  {
    public:
      StructLogin (char *buf): MemStruct (buf, LEN_LOGIN)
      {
      }

      // version
      short getVersion()
      {
        return *((short*)buf);
      }

      void setVersion (short val)
      {
        *((short*)buf) = val;
      }

      // osId
      char getOsId()
      {
        return *(buf + 2);
      }

      void setOsId (char val)
      {
        *(buf + 2) = val;
      }

      // platformId
      char getPlatformId()
      {
        return *(buf + 3);
      }

      void setPlatformId (char val)
      {
        *(buf + 3) = val;
      }

      // platformIdPwd
      char *getPlatformIdPwd()
      {
        return (buf + 4);
      }

      void setPlatformIdPwd (char *val)
      {
        memcpy (buf + 4, val, PLATFORM_ID_PWD_LEN);
      }

      // macId
      char *getMacId()
      {
        return (buf + 20);
      }

      void setMacId (char *val)
      {
        memcpy (buf + 20, val, MAC_ID_LEN);
      }

      // username
      char *getUsername()
      {
        return (buf + 26);
      }

      void setUsername (char *val)
      {
        memcpy (buf + 26, val, USERNAME_LEN);
      }

      // password
      char *getPassword()
      {
        return (buf + 90);
      }

      void setPassword (char *val)
      {
        memcpy (buf + 90, val, PASSWORD_LEN);
      }
  };
  

  // ---------------------------------------------------------------------------
  /**Class that gives interpretation of the char buffer. 
   *
   * It supposes that buffer has OTRequestTickStreamRequest_t structure.
   */
  class StructRequestTickStream: public MemStruct
  {
    public:
      StructRequestTickStream (char *buf): MemStruct (buf, LEN_REQUEST_TICK_STREAM)
      {
      }

      // sessionId
      char *getSessionId()
      {
        return buf;
      }

      void setSessionId (char *val)
      {
        memcpy (buf, val, SESSION_ID_LEN);
      }

      // exchange
      char *getExchange()
      {
        return (buf + 64);
      }

      void setExchange (char *val)
      {
        memcpy (buf + 64, val, EXCHANGE_CODE_LEN);
      }

      // symbol
      char *getSymbol()
      {
        return (buf + 79);
      }

      void setSymbol (char *val)
      {
        memcpy (buf + 79, val, SYMBOL_CODE_LEN);
      }
  };


  // ---------------------------------------------------------------------------
  /**Class that gives interpretation of the char buffer. 
   *
   * It supposes that buffer has OTRequestHistDataRequest_t structure.
   */
  class StructRequestHistData: public MemStruct
  {
    public:
      StructRequestHistData (char *buf): MemStruct (buf, LEN_REQUEST_HIST_DATA)
      {
      }

      // sessionId
      char *getSessionId()
      {
        return buf;
      }

      void setSessionId (char *val)
      {
        memcpy (buf, val, SESSION_ID_LEN);
      }

      // exchange
      char *getExchange()
      {
        return (buf + 64);
      }

      void setExchange (char *val)
      {
        memcpy (buf + 64, val, EXCHANGE_CODE_LEN);
      }

      // symbol
      char *getSymbol()
      {
        return (buf + 79);
      }

      void setSymbol (char *val)
      {
        memcpy (buf + 79, val, SYMBOL_CODE_LEN);
      }

      // startDate
      int getStartDate()
      {
        return *(int*)(buf + 94);
      }

      void setStartDate (int val)
      {
        *(int*)(buf + 94) = val;
      }

      // endDate
      int getEndDate()
      {
        return *(int*)(buf + 98);
      }

      void setEndDate (int val)
      {
        *(int*)(buf + 98) = val;
      }

      // dataType
      char getDataType()
      {
        return *(buf + 102);
      }

      void setDataType (char val)
      {
        *(buf + 102) = val;
      }

      // intervalValue
      short getIntervalValue()
      {
        return *(short*)(buf + 103);
      }

      void setIntervalValue (short val)
      {
        *(short*)(buf + 103) = val;
      }
  };


#endif
