/** \file OTSymbol.h
*   \brief OTSymbol class definition.
*
*   Copyright (C) 2004 Opentick corporation. All rights reserved.
*/

#ifndef _OT_SYMBOL_H
#define _OT_SYMBOL_H


#include "OTDef.h"


  /// <summary>
  /// Provides information about the symbol.
  /// </summary>
  class   OTSymbol 
  {
    public:
      /// <summary> Default constructor </summary>
      OTSymbol();

      /// <summary> Destructor </summary>
      ~OTSymbol();

      /// <returns>ID of the request which caused the message.</returns>
      int   getRequestId();      

      /// <returns>Instrument type.</returns>
      int   getType();

      /// <returns>String that identifies the equity, option, future, or index.</returns>
      char *getCode();

      /// <returns>Company name.</returns>
      char *getCompany();

      /// <returns>
      /// The currency for any prices provided in the events for this symbol;
      /// in the current system this value is “USD” for United States Dollars.
      /// </returns>
      char *getCurrency();
      
      /// <summary>
      /// Sets ID of the appropriate request.
      /// </summary>
      /// <param name="requestId">ID of the appropriate request.</param>
      void setRequestId (int requestId);

      /// <summary>
      /// Sets code of the symbol.
      /// </summary>
      /// <param name="code">String that identifies the equity, option, future, or index.</param>
      void setCode (const char *code);

      /// <summary>
      /// Sets company name.
      /// </summary>
      /// <param name="company">Company name.</param>
      void setCompany (const char *company);

      /// <summary>
      /// Sets currency.
      /// </summary>
      /// <param name="currency">Currency.</param>
      void setCurrency (const char *currency);

      /// <summary>
      /// Sets instrument type.
      /// </summary>
      /// <param name="type">Instrument type.</param>
      void setType (int type);
      
    private:
      OTSymbol (const OTSymbol &);
      OTSymbol & operator = (const OTSymbol &);

      int   requestId;      
      int   type;
      char *code;
      char *company;
      char *currency;

  };


#endif

