/** \file Socket.h
*   \brief Socket class definition
*
*   Copyright (C) 2004 Opentick corporation. All rights reserved.
*/


#ifndef _SOCKET_H
#define _SOCKET_H

#ifdef __WIN32
  #include <winsock2.h>
#endif

#ifdef __LINUX
  #include <netdb.h>
  #include <sys/types.h>
  #include <sys/time.h>
  #include <sys/socket.h>
  #include <netinet/in.h>    /* To define 'struct sockaddr_in' */
  #include <arpa/inet.h>
#endif

#define SOCK_SELECT_READ    1
#define SOCK_SELECT_WRITE   2
#define SOCK_SELECT_EXCEPT  3

#define SOCK_OK             10
#define SOCK_NODATA         20
#define SOCK_ERROR          30
#define SOCK_NOSOCKET       40

#ifdef __WIN32
  typedef int socklen_t;
#endif


/**Class that represents work with sockets.
 *
 * It incapsulates work with standart sockets.
 * Supports OOP.
 */
class Socket 
{
  public:
    Socket (int sockFd);
    Socket (int family, int type, int protocol);
    Socket();
    ~Socket();
    void create (int family, int type, int protocol);
    void bind (int &status, const char *ipAddress, int portNum);
    void listen (int &status, int backlog = 10);
    void connect (int &status, const char *ipAddress, int portNum);
    void close (int &status);
    void shutdown (int &status);
    int accept (int &status);
    
    int write (int &status, const char *str, int length);
    int read (int &status, char *buf, int length);

    void setTimeout (long sec, long usec);
    void setNonBlocking (int &status, bool enable = true);
    void setSockOpt (int &status, int level, int optname, const void *optval, socklen_t optlen);

    int fcntl (int &status, int cmd, unsigned long *arg = NULL);
    bool select (int &status, int type = SOCK_SELECT_READ);
    bool isValid();

    void joinMulticastGroup (int &status, const char *ipAddress);
    int recvFrom (int status, const char *buf, int len);
    char *getPeerIpAddress();

  protected:
    int                 sockFd;

  private:
    struct timeval      timeout;
    struct sockaddr_in  addr;
    bool                connected;
    bool                valid;

};

#endif
