/** \file Threads.h
*   \brief Event, CriticalSection, CSLock, FThread classes definition.
*
*   Copyright (C) 2004,2005 Opentick corporation. All rights reserved.
*/


#ifndef _THREADS_H
#define _THREADS_H

#include "OTDef.h"

#ifdef __WIN32
  #include <windows.h>
#endif

#ifdef __LINUX
  #include <pthread.h>
  #define INFINITE (-1)
#endif
  

  /**
      Event wrapper class.
  */  
  class   Event 
  {
    public:
      Event();
      ~Event();
      void set();
      void reset();
      void pulse();
      void wait (int timeout = INFINITE);

    private:
      #ifdef __WIN32
      HANDLE handle;
      #endif

      #ifdef __LINUX
      bool signaled;
      pthread_mutex_t mutex;
      pthread_cond_t cond;
      #endif
  };



  /** 
      Critical section wrapper class
  */  
  class   CriticalSection 
  {
    public:
      CriticalSection();
      ~CriticalSection();

      void enter();
      void leave();

    private:
      #ifdef __WIN32
      CRITICAL_SECTION handle;
      #endif

      #ifdef __LINUX
      pthread_mutex_t mutex;
      #endif
  };



  /**
      Critical section lock class.
  */
  class   CSLock 
  {
    public:
      CSLock (CriticalSection *cs);
      ~CSLock();

    private:
      CriticalSection *cs;
  };



  /**
     Thread class.
  */
  class   FThread 
  {
    public:
      FThread();
      ~FThread();
      bool create (void *func, void *param);
      void join();

      void setExitFlag (bool value);
      bool getExitFlag();

    private:
      CriticalSection csExitFlag;
      bool exitFlag;
      
      #ifdef __WIN32
      HANDLE handle;
      #endif

      #ifdef __LINUX
      pthread_t handle;
      #endif
  };


#endif
